@@ -71,7 +71,7 @@ CAIXS_entersub(pTHX) {
     typedef void (*XSPROTO_CB)(pTHX_ CV*);
 
     CV* sv = (CV*)TOPs;
-    if (sv && (SvTYPE(sv) == SVt_PVCV) && (CvXSUB(sv) == (XSPROTO_CB)&CAIXS_accessor<type>)) {
+    if (LIKELY(sv && (SvTYPE(sv) == SVt_PVCV) && (CvXSUB(sv) == (XSPROTO_CB)&CAIXS_accessor<type>))) {
         /*
             Assert against future XPVCV layout change - as for now, xcv_xsub shares space with xcv_root
             which are both pointers, so address check is enough, and there's no need to look into op_flags for CvISXSUB.
@@ -99,9 +99,11 @@ CAIXS_install_entersub(pTHX) {
     */
 
     OP* op = PL_op;
-    if ((op->op_spare & 1) != 1 && op->op_ppaddr == PL_ppaddr[OP_ENTERSUB] && optimize_entersub) {
-        op->op_spare |= 1;
-        op->op_ppaddr = &CAIXS_entersub<type>;
+    if ((op->op_spare & 1) != 1) {
+        if (LIKELY(op->op_ppaddr == PL_ppaddr[OP_ENTERSUB] && optimize_entersub)) {
+            op->op_spare |= 1;
+            op->op_ppaddr = &CAIXS_entersub<type>;
+        }
     }
 }
 
@@ -112,7 +114,7 @@ CAIXS_find_keys(CV* cv) {
 #ifndef MULTIPLICITY
     /* Blessed are ye and get a fastpath */
     keys = (shared_keys*)(CvXSUBANY(cv).any_ptr);
-    if (!keys) croak("Can't find hash key information");
+    if (UNLIKELY(!keys)) croak("Can't find hash key information");
 #else
     /*
         We can't look into CvXSUBANY under threads, as it would have been written in the parent thread
@@ -120,7 +122,7 @@ CAIXS_find_keys(CV* cv) {
         refcnt storage - there's always a proper thread-local SV*, cloned for us by perl itself.
     */
     MAGIC* mg = mg_findext((SV*)cv, PERL_MAGIC_ext, &sv_payload_marker);
-    if (!mg) croak("Can't find hash key information");
+    if (UNLIKELY(!mg)) croak("Can't find hash key information");
 
     keys = (shared_keys*)AvARRAY((AV*)(mg->mg_obj));
 #endif
@@ -133,7 +135,7 @@ XSPROTO(CAIXS_accessor<PrivateClass>) {
     dXSARGS;
     SP -= items;
 
-    if (!items) croak("Usage: $obj->accessor or __PACKAGE__->accessor");
+    if (UNLIKELY(!items)) croak("Usage: $obj->accessor or __PACKAGE__->accessor");
 
     CAIXS_install_entersub<PrivateClass>(aTHX);
     shared_keys* keys = (shared_keys*)CAIXS_find_keys(cv);
@@ -151,7 +153,7 @@ XSPROTO(CAIXS_accessor) {
     dXSARGS;
     SP -= items;
 
-    if (!items) croak("Usage: $obj->accessor or __PACKAGE__->accessor");
+    if (UNLIKELY(!items)) croak("Usage: $obj->accessor or __PACKAGE__->accessor");
 
     CAIXS_install_entersub<type>(aTHX);
     shared_keys* keys = CAIXS_find_keys(cv);
@@ -159,7 +161,7 @@ XSPROTO(CAIXS_accessor) {
     SV* self = *(SP+1);
     if (SvROK(self)) {
         HV* obj = (HV*)SvRV(self);
-        if (SvTYPE((SV*)obj) != SVt_PVHV) {
+        if (UNLIKELY(SvTYPE((SV*)obj) != SVt_PVHV)) {
             croak("Inherited accessors can only work with object instances that is hash-based");
         }
 
@@ -189,14 +191,14 @@ XSPROTO(CAIXS_accessor) {
 
     } else {
         GV* acc_gv = CvGV(cv);
-        if (!acc_gv) croak("Can't have pkg accessor in anon sub");
+        if (UNLIKELY(!acc_gv)) croak("Can't have pkg accessor in anon sub");
         stash = GvSTASH(acc_gv);
 
         const char* stash_name = HvNAME(stash);
         const char* self_name = SvPV_nolen(self);
         if (strcmp(stash_name, self_name) != 0) {
             stash = gv_stashsv(self, GV_ADD);
-            if (!stash) croak("Couldn't get required stash");
+            if (UNLIKELY(!stash)) croak("Couldn't get required stash");
         }
     }
 
