@@ -19,4 +19,8 @@
 #define gv_init_sv(gv, stash, sv, flags) gv_init(gv, stash, SvPVX(sv), SvLEN(sv), flags | SvUTF8(sv))
 #endif
 
+#if (PERL_VERSION < 16)
+#define Perl_newXS_len_flags(name, len, subaddr, filename, proto, const_svp, flags) Perl_newXS_flags(name, subaddr, filename, proto, flags)
+#endif
+
 #endif /* __INHERITED_XS_COMPAT_H_ */
